@@ -34,8 +34,11 @@ from __future__ import print_function
 
 from __future__ import absolute_import
 
-import os, sys, time, re, getopt, getpass
-import pexpect, pxssh
+import os
+import sys
+import getopt
+import getpass
+import pxssh
 
 
 try:
